@@ -10,7 +10,7 @@ import os
 import numpy as np
 import pandas as pd
 import scipy
-from tqdm import tqdm
+from scipy.sparse import issparse
 
 import torch
 from torch.utils.data import Dataset
@@ -70,7 +70,7 @@ def load_file(path):
     else:
         raise ValueError("File {} not exists".format(path))
         
-    if type(adata.X) == np.ndarray:
+    if not issparse(adata.X):
         adata.X = scipy.sparse.csr_matrix(adata.X)
     adata.var_names_make_unique()
     return adata
@@ -134,49 +134,33 @@ def preprocessing(
     preprocessing
     """
     if log: log.info('Preprocessing')
-    if type(adata.X) == np.ndarray:
+    if not issparse(adata.X):
         adata.X = scipy.sparse.csr_matrix(adata.X)
     
     adata = adata[:, [gene for gene in adata.var_names 
                   if not str(gene).startswith(tuple(['ERCC', 'MT-', 'mt-']))]]
     
     if log: log.info('Filtering cells')
-    cell_subsets = []
-    for i in range(adata.shape[0]//chunk_size+1):
-        cell_subset, _ = sc.pp.filter_cells(adata[i*chunk_size:(i+1)*chunk_size], min_genes=min_genes, inplace=False)
-        cell_subsets.append(cell_subset)
-    indices = np.where(np.concatenate(cell_subsets))[0]
-    adata = adata[indices]
+    sc.pp.filter_cells(adata, min_genes=min_genes)
     
     if log: log.info('Filtering genes')
     sc.pp.filter_genes(adata, min_cells=min_cells)
-#     adata = adata[np.where(np.sum(adata.X>0, 0))]
-#     gene_set, _ = sc.pp.filter_genes(adata, min_cells=min_cells, inplace=False)
-#     log.info('subset gene')
-#     adata = adata[:, np.where(gene_set)[0]]
 
-    if log: log.info('Normalizing total to {}'.format(target_sum))
-    X_ = []
-    for i in range(adata.shape[0]//chunk_size+1):
-        X = sc.pp.normalize_total(adata[i*chunk_size:(i+1)*chunk_size], target_sum=target_sum, exclude_highly_expressed=True, inplace=False)['X']
-        X_.append(X)
-#     sc.pp.normalize_total(adata, target_sum=target_sum, exclude_highly_expressed=True)
-    adata.X = scipy.sparse.vstack(X_)
-    del X_
-    del X
+    if log: log.info('Normalizing total per cell')
+    sc.pp.normalize_total(adata, target_sum=target_sum)
     
     if log: log.info('Log1p transforming')
-    sc.pp.log1p(adata) #, chunked=True, chunk_size=chunk_size)
+    sc.pp.log1p(adata)
     
+    adata.raw = adata
     if log: log.info('Finding variable genes')
     if type(n_top_genes) == int and n_top_genes>0:
         sc.pp.highly_variable_genes(adata, n_top_genes=n_top_genes, batch_key='batch', inplace=False, subset=True)
-    else:
+    elif type(n_top_genes) != int:
         adata = reindex(adata, n_top_genes)
         
     if log: log.info('Batch specific maxabs scaling')
     adata = batch_scale(adata, chunk_size=chunk_size)
-    
     if log: log.info('Processed dataset shape: {}'.format(adata.shape))
     return adata
     
@@ -194,14 +178,15 @@ def batch_scale(adata, chunk_size=CHUNK_SIZE):
     return adata
         
 
-def reindex(adata, genes):
+def reindex(adata, genes, chunk_size=CHUNK_SIZE):
     """
     Reindex AnnData with gene list
     """
     idx = [i for i, g in enumerate(genes) if g in adata.var_names]
     print('There are {} gene in selected genes'.format(len(idx)))
     new_X = scipy.sparse.csr_matrix((adata.shape[0], len(genes)))
-    new_X[:, idx] = adata[:, genes[idx]].X
+    for i in range(new_X.shape[0]//chunk_size+1):
+        new_X[i*chunk_size:(i+1)*chunk_size, idx] = adata[i*chunk_size:(i+1)*chunk_size, genes[idx]].X
     adata = AnnData(new_X, obs=adata.obs, var={'var_names':genes}) 
     return adata
 
@@ -268,7 +253,6 @@ def load_dataset(
         n_top_genes=2000, 
         batch_size=64, 
         chunk_size=CHUNK_SIZE,
-        partial=False,
         log=None,
     ):
     """
@@ -299,9 +283,6 @@ def load_dataset(
         num_workers=4
     )
     batch_sampler = BatchSampler(batch_size, adata.obs['batch'], drop_last=False)
-    if partial:
-        testloader = DataLoader(scdata, batch_size=batch_size, drop_last=False, shuffle=True)
-    else:
-        testloader = DataLoader(scdata, batch_sampler=batch_sampler)
+    testloader = DataLoader(scdata, batch_sampler=batch_sampler)
     
     return adata, trainloader, testloader 
\ No newline at end of file
