@@ -13,6 +13,7 @@ import numpy as np
 import os
 import scanpy as sc
 from anndata import AnnData
+from sklearn.metrics import silhouette_score
 
 from .dataset import load_dataset
 from .net.vae import VAE
@@ -42,8 +43,8 @@ def SCALEX(
         impute=None, 
         chunk_size=20000,
         ignore_umap=False,
-        partial=False,
         verbose=False,
+        assess=False,
     ):
     
 #     sc.logging.print_versions()
@@ -70,17 +71,15 @@ def SCALEX(
             min_cells=min_cells,
             batch_name=batch_name, 
             batch_key=batch_key,
-            partial=partial,
             log=log
         )
-#         log.info('Processed dataset shape: {}'.format(adata.shape))
         
         early_stopping = EarlyStopping(patience=10, checkpoint_file=outdir+'/checkpoint/model.pt')
         x_dim, n_domain = adata.shape[1], len(adata.obs['batch'].cat.categories)
         enc = [['fc', 1024, 1, 'relu'],['fc', 10, '', '']]  # TO DO
         dec = [['fc', x_dim, n_domain, 'sigmoid']]
         model = VAE(enc, dec, n_domain=n_domain)
-#         log.info('model\n'+model.__repr__())
+        log.info('model\n'+model.__repr__())
         model.fit(
             trainloader, testloader=testloader,
             lr=lr, 
@@ -105,14 +104,13 @@ def SCALEX(
             min_cells=0,
             batch_name=batch_name,
             batch_key=batch_key,
-            partial=partial,
             log = log
         )
 #         log.info('Processed dataset shape: {}'.format(adata.shape))
         
     adata.obsm['latent'] = model.encodeBatch(testloader, device=device) # save latent rep
     if impute:
-        adata.layers['impute'] = model.encodeBatch(testloader, out='impute', device=device)
+        adata.layers['impute'] = model.encodeBatch(testloader, out='impute', batch_id=impute, device=device)
     log.info('Output dir: {}'.format(outdir))
         
     if projection and (not repeat):
@@ -140,14 +138,15 @@ def SCALEX(
                 plot_umap(adata, cond1='projection', save='.pdf')
             else:
                 sc.pl.umap(adata, color=color, save='.pdf', wspace=0.4, ncols=4)
-                
-#         if len(adata.obs['batch'].cat.categories) > 1:
-#             entropy_score = entropy_batch_mixing(adata.obsm['X_umap'], adata.obs['batch'])
-#             log.info('entropy_batch_mixing: {:.3f}'.format(entropy_score))
+           
+        if assess:
+            if len(adata.obs['batch'].cat.categories) > 1:
+                entropy_score = entropy_batch_mixing(adata.obsm['X_umap'], adata.obs['batch'])
+                log.info('entropy_batch_mixing: {:.3f}'.format(entropy_score))
 
-#         if 'celltype' in adata.obs:
-#             sil_score = silhouette_score(adata.obsm['X_umap'], adata.obs['celltype'].cat.codes)
-#             log.info("silhouette_score: {:.3f}".format(sil_score))
+            if 'celltype' in adata.obs:
+                sil_score = silhouette_score(adata.obsm['X_umap'], adata.obs['celltype'].cat.codes)
+                log.info("silhouette_score: {:.3f}".format(sil_score))
 
     adata.write(outdir+'adata.h5ad', compression='gzip')
         
