@@ -64,6 +64,57 @@ def plot_umap(
             sc.pl.diffmap(adata, color='tmp', groups=groups, title=title, palette=palette, size=size, save=save_,
                    legend_loc=legend_loc, legend_fontsize=legend_fontsize, legend_fontweight=legend_fontweight)
         del adata.obs['tmp']
+        del adata.uns['tmp_colors']
+        
+        
+def plot_umap2(
+        adata, 
+        color='celltype', 
+        color_map=None, 
+        groupby='batch', 
+        groups=None, 
+        cond2=None, 
+        v2=None, 
+        save=None, 
+        legend_loc='right margin', 
+        legend_fontsize=None, 
+        legend_fontweight='bold', 
+        sep='_', 
+        basis='umap'
+    ):
+    
+    if groups is None:
+        groups = adata.obs[groupby].cat.categories
+    for b in groups:
+        adata.obs['tmp'] = adata.obs[color]
+        adata.obs['tmp'][adata.obs[groupby]!=b] = 0
+        if cond2 is not None:
+            adata.obs.loc[adata.obs[cond2]!=v2, 'tmp'] = ''
+            groups = list(adata[(adata.obs[cond1]==b) & 
+                                (adata.obs[cond2]==v2)].obs[color].astype('category').cat.categories.values)
+            size = min(10, 120000/len(adata[(adata.obs[cond1]==b) & (adata.obs[cond2]==v2)]))
+        else:
+#             groups = list(adata[adata.obs[cond1]==b].obs[color].astype('category').cat.categories.values)
+            size = min(10, 120000/len(adata[adata.obs[cond1]==b]))
+        adata.obs['tmp'] = adata.obs['tmp'] #.astype('category')
+#         if color_map is not None:
+#             palette = [color_map[i] if i in color_map else 'gray' for i in adata.obs['tmp'].cat.categories]
+#         else:
+#             palette = None
+
+        title = b if cond2 is None else v2+sep+b
+        if save is not None:
+            save_ = '_'+b+save
+        else:
+            save_ = None
+        if basis == 'umap':
+            sc.pl.umap(adata, color='tmp', groups=groups, title=title, palette=palette, size=size, save=save_,
+                   legend_loc=legend_loc, legend_fontsize=legend_fontsize, legend_fontweight=legend_fontweight)
+        elif basis == 'diffmap':
+            sc.pl.diffmap(adata, color='tmp', groups=groups, title=title, palette=palette, size=size, save=save_,
+                   legend_loc=legend_loc, legend_fontsize=legend_fontsize, legend_fontweight=legend_fontweight)
+        del adata.obs['tmp']
+        del adata.uns['tmp_colors']
 
             
 def plot_legend(color_map, savefig=None, figsize=(0.1, 0.1), ncol=1, title='', marker='o'):
@@ -79,8 +130,8 @@ def plot_legend(color_map, savefig=None, figsize=(0.1, 0.1), ncol=1, title='', m
         plt.show()
         
 
-def plot_meta2(adata, use_rep='latent', var='celltype', batch='batch', color_map=None, figsize=(10, 10), cmap='Blues',
-              batches=None, annot=False, savefig=None, cbar=True, keep=False):
+def plot_meta2(adata, use_rep='latent', color='celltype', batch='batch', color_map=None, figsize=(10, 10), cmap='Blues',
+              batches=None, annot=False, savefig=None, cbar=True, keep=False, fontsize=8, vmin=0, vmax=1):
     """
     input: AnnData
     """
@@ -88,13 +139,13 @@ def plot_meta2(adata, use_rep='latent', var='celltype', batch='batch', color_map
     name = []
 #     if colors is None:
 #         colors = ['red', 'royalblue', 'lawngreen', 'orange', 'gold',  'lightseagreen', 'blueviolet', 'black']
-#     adata.obs[var] = adata.obs[var].astype('category')
+    adata.obs[color] = adata.obs[color].astype('category')
     if batches is None:
         batches = np.unique(adata.obs[batch]);#print(batches)
 
     for i,b in enumerate(batches):
-        for cat in adata.obs[var].cat.categories:
-            index = np.where((adata.obs[var]==cat) & (adata.obs[batch]==b))[0]
+        for cat in adata.obs[color].cat.categories:
+            index = np.where((adata.obs[color]==cat) & (adata.obs[batch]==b))[0]
             if len(index) > 0:
                 if use_rep and use_rep in adata.obsm:
                     meta.append(adata.obsm[use_rep][index].mean(0))
@@ -121,18 +172,18 @@ def plot_meta2(adata, use_rep='latent', var='celltype', batch='batch', color_map
         y_ind = [i for i,k in enumerate(categories) if k in yticklabels]
         corr_[np.ix_(y_ind, x_ind)] = corr
         corr = corr_
-#         xticklabels, yticklabels = categories, categories
-        xticklabels, yticklabels = [], []
+        xticklabels, yticklabels = categories, categories
+#         xticklabels, yticklabels = [], []
     grid = sns.heatmap(corr, xticklabels=xticklabels, yticklabels=yticklabels, annot=annot,
-                cmap=cmap, square=True, cbar=cbar, vmin=0, vmax=1)
+                cmap=cmap, square=True, cbar=cbar, vmin=vmin, vmax=vmax)
 
     if color_map is not None:
         [ tick.set_color(color_map[tick.get_text()]) for tick in grid.get_xticklabels() ]
         [ tick.set_color(color_map[tick.get_text()]) for tick in grid.get_yticklabels() ]
-    plt.xticks(rotation=45, horizontalalignment='right', fontsize=18)
-    plt.yticks(fontsize=18)
-    plt.xlabel(batches[0], fontsize=18)
-    plt.ylabel(batches[1], fontsize=18)
+    plt.xticks(rotation=45, horizontalalignment='right', fontsize=fontsize)
+    plt.yticks(fontsize=fontsize)
+    plt.xlabel(batches[0], fontsize=fontsize)
+    plt.ylabel(batches[1], fontsize=fontsize)
     
 #     rainbow_text(15, 1, batches, colors[:len(batches)], size=14)#, ax=grid)
 #     plt.xlabel('\n'.join([b+' : '+colors[i] for i,b in enumerate(np.unique(adata.obs.batch))]))
@@ -142,8 +193,8 @@ def plot_meta2(adata, use_rep='latent', var='celltype', batch='batch', color_map
         plt.show()
         
 
-def plot_meta(adata, use_rep=None, var='celltype', batch='batch', colors=None, cmap='Blues', vmax=1, vmin=0, mask=True,
-              annot=False, savefig=None):
+def plot_meta(adata, use_rep=None, color='celltype', batch='batch', colors=None, cmap='Blues', vmax=1, vmin=0, mask=True,
+              annot=False, savefig=None, fontsize=8):
     """
     input: AnnData
     """
@@ -152,14 +203,19 @@ def plot_meta(adata, use_rep=None, var='celltype', batch='batch', colors=None, c
     color = []
 #     colors = ['red', 'blue', 'green', 'orange', 'yellow', 'purple', 'black']
     if colors is None:
-        colors = ['red', 'orange', 'gold', 'lawngreen', 'lightseagreen', 'royalblue', 'blueviolet', 'black']
-    adata.obs[var] = adata.obs[var].astype('category')
+        colors = ['#FFFF00', '#1CE6FF', '#FF34FF', '#FF4A46', '#008941', '#006FA6', '#A30059', '#FFDBE5', '#7A4900', '#0000A6',
+                  '#63FFAC', '#B79762', '#004D43', '#8FB0FF', '#997D87', '#5A0007', '#809693', '#6A3A4C', '#1B4400', '#4FC601',
+                  '#3B5DFF', '#4A3B53', '#FF2F80', '#61615A', '#BA0900', '#6B7900', '#00C2A0', '#FFAA92', '#FF90C9', '#B903AA',
+                  '#D16100', '#DDEFFF', '#000035', '#7B4F4B', '#A1C299', '#300018', '#0AA6D8', '#013349', '#00846F', '#372101',
+                  '#FFB500', '#C2FFED', '#A079BF', '#CC0744', '#C0B9B2', '#C2FF99', '#001E09']
+#         colors = ['red', 'orange', 'gold', 'lawngreen', 'lightseagreen', 'royalblue', 'blueviolet', 'black']
+    adata.obs[color] = adata.obs[color].astype('category')
     batches = np.unique(adata.obs[batch])
     for i,b in enumerate(batches):
-        for cat in adata.obs[var].cat.categories:
-#     for cat in adata.obs[var].cat.categories:
+        for cat in adata.obs[color].cat.categories:
+#     for cat in adata.obs[color].cat.categories:
 #         for i,b in enumerate(batches):
-            index = np.where((adata.obs[var]==cat) & (adata.obs[batch]==b))[0]
+            index = np.where((adata.obs[color]==cat) & (adata.obs[batch]==b))[0]
             if len(index) > 0:
                 if use_rep and use_rep in adata.obsm:
                     meta.append(adata.obsm[use_rep][index].mean(0))
@@ -184,8 +240,8 @@ def plot_meta(adata, use_rep=None, var='celltype', batch='batch', colors=None, c
                 cmap=cmap, square=True, cbar=True, vmin=vmin, vmax=vmax)
     [ tick.set_color(c) for tick,c in zip(grid.get_xticklabels(),color) ]
     [ tick.set_color(c) for tick,c in zip(grid.get_yticklabels(),color) ]
-    plt.xticks(rotation=45, horizontalalignment='right', fontsize=10)
-    plt.yticks(fontsize=10)
+    plt.xticks(rotation=45, horizontalalignment='right', fontsize=fontsize)
+    plt.yticks(fontsize=fontsize)
 #     rainbow_text(15, 1, batches, colors[:len(batches)], size=14)#, ax=grid)
 #     plt.xlabel('\n'.join([b+' : '+colors[i] for i,b in enumerate(np.unique(adata.obs.batch))]))
     if savefig:
